@@ -19,7 +19,7 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2013 PgPool Global Development Group
+ * @copyright  2003-2016 PgPool Global Development Group
  * @version    CVS: $Id$
  */
 
@@ -32,7 +32,7 @@ require_once('common.php');
  * @param srgs $num
  * @return array
  */
-function execPcp($command, $num = '')
+function execPcp($command, $extra_args = array())
 {
     $pcpStatus = array (
         '0'   => 'SUCCESS',
@@ -55,12 +55,27 @@ function execPcp($command, $num = '')
     $param = readPcpInfo();
     $param['hostname'] = _PGPOOL2_PCP_HOSTNAME;
 
-    $args = " " . PCP_TIMEOUT.
-            " " . $param['hostname'] .
-            " " . $param['pcp_port'] .
-            " ". $_SESSION[SESSION_LOGIN_USER] .
-            " '" . $_SESSION[SESSION_LOGIN_USER_PASSWORD] . "' " .
-            $num;
+    if (3.5 <= _PGPOOL2_VERSION) {
+        // Check /home/apache/.pcppass (If error, exit here)
+        checkPcppass();
+
+        $args = sprintf(' -w -h %s -p %d -U %s',
+            $param['hostname'], $param['pcp_port'],
+            $_SESSION[SESSION_LOGIN_USER]
+        );
+
+        foreach ($extra_args as $arg_name => $val) {
+            $args .= " -{$arg_name} {$val}";
+        }
+
+    } elseif ($param) {
+        $args = " " . PCP_TIMEOUT.
+                " " . $param['hostname'] .
+                " " . $param['pcp_port'] .
+                " ". $_SESSION[SESSION_LOGIN_USER] .
+                " '" . $_SESSION[SESSION_LOGIN_USER_PASSWORD] . "' " .
+                implode($extra_args, ' ');
+    }
 
     switch ($command) {
         case 'PCP_NODE_COUNT':
@@ -95,22 +110,8 @@ function execPcp($command, $num = '')
             break;
 
         case 'PCP_START_PGPOOL':
-            $configOption = ' -f ' . _PGPOOL2_CONFIG_FILE .
-                            ' -F ' . _PGPOOL2_PASSWORD_FILE;
-
-            if(isPipe($num)) {
-                $cmdOption = $configOption . $num . ' > /dev/null &';
-            } else {
-                $cmdOption = $configOption . $num . ' 2>&1 &';
-            }
-
-            /* we should not check pid file here.
-             * let pgpool handle bogus pid file
-             * if(DoesPgpoolPidExist()) {
-             *   return array('FAIL'=> '');
-             * }
-             */
-            $cmd = _PGPOOL2_COMMAND . $cmdOption;
+            $args = _setStartArgs();
+            $cmd = _PGPOOL2_COMMAND . $args;
             $ret = exec($cmd, $output, $return_var);
             if ($return_var == 0) {
                 return array($pcpStatus[$return_var] => $output);
@@ -120,11 +121,8 @@ function execPcp($command, $num = '')
             break;
 
         case 'PCP_RELOAD_PGPOOL':
-            $cmdOption = $num;
-            $cmdOption = $cmdOption .
-                         ' -f ' . _PGPOOL2_CONFIG_FILE .
-                         ' -F ' . _PGPOOL2_PASSWORD_FILE . ' reload';
-            $cmd = _PGPOOL2_COMMAND . $cmdOption . ' 2>&1 &';
+            $args = _setStartArgs();
+            $cmd = _PGPOOL2_COMMAND . $args. ' reload 2>&1 &';
             $ret = exec($cmd, $output, $return_var);
             if ($return_var == 0) {
                 return array($pcpStatus[$return_var] => $output);
@@ -134,6 +132,7 @@ function execPcp($command, $num = '')
             break;
 
         case 'PCP_STOP_PGPOOL':
+            $args .= " {$_POST['stop_mode']}";
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_stop_pgpool' . $args;
             $ret = exec($cmd, $output, $return_var);
             break;
@@ -153,11 +152,15 @@ function execPcp($command, $num = '')
         case 'PCP_WATCHDOG_INFO':
             $cmd = _PGPOOL2_PCP_DIR . '/pcp_watchdog_info' . $args;
             $ret = exec($cmd, $output, $return_var);
+            if (3.5 <= _PGPOOL2_VERSION) {
+                $ret = $output[2];
+            }
             break;
 
         default:
             return array($pspStatus[1] => $pspStatus[1]);
     }
+
     return array($pcpStatus[$return_var] => $ret);
 }
 
@@ -195,12 +198,11 @@ function getNodeInfo($i)
     global $tpl;
 
     // execute "pcp_node_info" command
-    // ex) host1 5432 1 1073741823.500000
-    $result = execPcp('PCP_NODE_INFO', $i);
+    $result = execPcp('PCP_NODE_INFO', array('n' => $i));
 
     if (!array_key_exists('SUCCESS', $result)) {
-        $errorCode = 'e1003';
-        $tpl->assign('errorCode', $errorCode);
+        $tpl->assign('errorCode', 'e1003');
+        $tpl->assign('result', $result);
         $tpl->display('innerError.tpl');
         exit();
     }
@@ -219,24 +221,60 @@ function getNodeInfo($i)
  */
 function getWatchdogInfo($i = '')
 {
-    global $tpl;
+    global $tpl, $g_watchdog_status_str_arr;
 
+    $result = execPcp('PCP_WATCHDOG_INFO',
+        (3.5 <= _PGPOOL2_VERSION) ? array('n' => $i) : array($i)
+    );
 
-    $result = execPcp('PCP_WATCHDOG_INFO', $i);
-
-    if (!array_key_exists('SUCCESS', $result)) {
-        $errorCode = 'e1003';
+    if (! array_key_exists('SUCCESS', $result)) {
+        $errorCode = 'e1013';
         $tpl->assign('errorCode', $errorCode);
         $tpl->display('innerError.tpl');
         exit();
     }
 
-    $arr = explode(" ", $result['SUCCESS']);
-    $rtn['hostname']    = $arr[0];
-    $rtn['pgpool_port'] = $arr[1];
-    $rtn['wd_port']     = $arr[2];
-    $rtn['status']      = $arr[3];
+    $arr = explode(' ', $result['SUCCESS']);
 
+    if (3.5 <= _PGPOOL2_VERSION) {
+        // ex.) Linux_dhcp-177-180_9999 133.137.177.180 9999 9000 4 MASTER
+        $rtn['hostname']    = $arr[1];
+        $rtn['pgpool_port'] = $arr[2];
+        $rtn['wd_port']     = $arr[3];
+        $rtn['status']      = $arr[4];
+        $rtn['status_str']  = $arr[5];
+
+    } else {
+        // ex.) 133.137.177.180 9999 9000 3
+        $rtn['hostname']    = $arr[0];
+        $rtn['pgpool_port'] = $arr[1];
+        $rtn['wd_port']     = $arr[2];
+        $rtn['status']      = $arr[3];
+        $rtn['status_str']  = $g_watchdog_status_str_arr[$rtn['status']];
+    }
     return $rtn;
 }
-?>
+
+function checkPcppass()
+{
+    global $message, $tpl;
+
+    $proc_user_info = posix_getpwuid(posix_geteuid());
+    $pcppass_file = "{$proc_user_info['dir']}/.pcppass";
+
+    $detail = NULL;
+    if (! is_file($pcppass_file)) {
+        $detail = $message['errFileNotFound'];
+    } elseif (fileowner($pcppass_file) != $proc_user_info['uid']) {
+        $detail = $message['errInvalidOwner'];
+    } elseif (substr(sprintf('%o', fileperms($pcppass_file)), -4) != '0600') {
+        $detail = $message['errInvalidPermission'];
+    }
+
+    if ($detail) {
+        $tpl->assign('errorCode', 'e1014');
+        $tpl->assign('detail', $detail);
+        $tpl->display('innerError.tpl');
+        exit();
+    }
+}
