@@ -41,6 +41,7 @@ $message = array(
     'descBlack_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
     'descBlack_memqcache_table_list' => 'SELECT結果をキャッシュしたくないテーブル名のカンマ区切りのリスト',
     'descCheck_temp_table' => '一時テーブルかどうかをチェック',
+    'descCheck_unlogged_table' => 'unloggedテーブルかどうかをチェック',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
     'descChild_max_connections' => '各pgpool子プロセスが終了するまでの接続回数',
     'descClear_memqcache_on_escalation' => 'アクティブ昇格時に共有メモリ上のクエリキャッシュを削除するかどうか',
@@ -49,7 +50,7 @@ $message = array(
     'descClient_min_messages' => 'クライアントに送るログの詳細レベル',
     'descConnection_cache' => 'コネクションキャッシュ機能の有無',
     'descConnection_life_time' => 'コネクションプール中のコネクションの有効期間(秒)',
-    'desCconnect_timeout' => 'connect()システムコールを使ってバックエンドに接続する際のタイムアウト値を指定（ミリ秒）',
+    'descConnect_timeout' => 'connect()システムコールを使ってバックエンドに接続する際のタイムアウト値を指定（ミリ秒）',
     'descDatabase_redirect_preference_list' => 'データベース名によって負荷分散をしたいノード番号を、"データベース名:ノード番号"で指定',
     'descDebug_level' => 'デバッグメッセージの詳細レベル（0は無効）',
     'descDelay_threshold' => '許容するスタンバイサーバの遅延(バイト)',
@@ -64,13 +65,15 @@ $message = array(
     'descHeartbeat_destination' => 'ハートビート信号の送信先ホスト名または IP アドレス',
     'descHeartbeat_destination_port' => 'ハートビート信号の送信先ポート番号',
     'descHeartbeat_device' => 'ハートビートの送受信に用いるネットワークデバイス名',
-    'descHealth_check_period' => 'ヘルスチェックを行う間隔(秒)',
+    'descHealth_check_database' => 'ヘルスチェックを行う対象のデータベース名',
+    'descHealth_check_period' => 'ヘルスチェックを行なう間隔(秒)',
     'descHealth_check_timeout' => 'ヘルスチェックが長時間待たされるのを防ぐためのタイムアウト値(秒)',
     'descHealth_check_user' => 'ヘルスチェックを行うためのPostgreSQLユーザ名',
     'descHealth_check_password' => 'ヘルスチェックを行うためのPostgreSQLパスワード',
     'descHealth_check_max_retries' => 'ヘルスチェックに失敗した後にリトライする回数',
     'descHealth_check_retry_delay' => 'ヘルスチェックのリトライの間の間隔（秒）',
     'descIfconfig_path' => 'ifconfig コマンドのパス',
+    'descIf_cmd_path' => 'if コマンドのパス',
     'descIf_down_cmd' => '仮想 IP を停止するために実行するコマンド',
     'descIf_up_cmd' => '仮想 IP を起動するために実行するコマンド',
     'descIgnore_leading_white_space' => 'load balance時のSQL文行頭の空白を無視',
@@ -110,13 +113,14 @@ $message = array(
     'descOther_pgpool_port' => '監視する pgpool-II が稼働するポート番号',
     'descOther_wd_port' => '監視する watchdog が稼働するポート番号',
     'descParallel_mode' => 'パラレルモードでpgpoolを運転',
-    'descPcp_port' => 'pgpool-IIが受け付けているポート番号',
+    'descPcp_port' => 'pcpがTCP/IPコネクションを受け付けるポート番号',
+    'descPcp_listen_addresses' => 'pcpがTCP/IPコネクションを受け付けるアドレス',
     'descPcp_socket_dir' => 'pcpがコネクションを受け付けるUnix domain socketディレクトリ',
     'descPcp_timeout' => 'この時間内にクライアントから応答がない場合はコネクションを切断して終了',
     'descPgpool2_hostname' => 'pgpool2 が動作しているホスト名',
     'descPool_passwd' => 'md5 認証で用いる認証ファイル',
     'descPing_path' => 'ping コマンドのパス',
-    'descPort' => 'pgpoolがコネクションを受け付けるポート番号',
+    'descPort' => 'pgpoolがTCP/IPコネクションを受け付けるポート番号',
     'descPrint_timestamp' => 'pgpoolのログにタイムスタンプを追加',
     'descRecovery_user' => 'リカバリを行うためのPostgreSQLユーザ',
     'descRecovery_password' => 'リカバリを行うためのPostgreSQLユーザパスワード',
@@ -131,12 +135,15 @@ $message = array(
     'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間。'.
                                  '厳密でないレプリケーションモードでは、デッドロックが発生しやすくなります。',
     'descReset_query_list' => 'セッションが終了するときにコネクションを初期化するためのSQLコマンド',
+    'descSearch_primary_node_timeout' => 'フェイルオーバーが起きた時にプライマリノードを検索する際のタイムアウト時間(秒)',
+    'descSerialize_accept' => 'クライアントからの接続受け付け時、accept() をシリアライズする',
     'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
     'descSsl' => 'pgpool-IIとバックエンドの間のSSL接続',
     'descSsl_ca_cert' => 'opensslの-CAFileに指定するパス',
     'descSsl_ca_cert_dir' => 'opensslの-CApathに指定するディレクトリパス',
     'descSsl_cert' => 'フロントエンドとの接続に使用する公開x509証明書のフルパス',
     'descSsl_key' => 'フロントエンドとの接続に使用するプライベートキーファイルのフルパス',
+    'descSr_check_database' => 'ストリーミングレプリケーションの遅延チェックを行なう対象のデータベース名',
     'descSr_check_period' => 'ストリーミングレプリケーションの遅延チェックの間隔(秒)',
     'descSr_check_user' => 'ストリーミングレプリケーションの遅延チェックを行うユーザ',
     'descSr_check_password' => 'ストリーミングレプリケーションの遅延チェックを行うユーザのパスワード',
@@ -151,19 +158,23 @@ $message = array(
     'descTrusted_servers' => '上位サーバのコンマ区切りのリスト',
     'descUse_watchdog' => 'watchdog 機能の有無',
     'descWd_authkey' => 'wachdog 間通信で用いられる認証キー',
-    'descWd_escalation_command' => 'アクティブ昇格時に実行するコマンド',
+    'descWd_de_escalation_command' => 'マスタ（コーディネータ）降格時に実行するコマンド',
+    'descWd_escalation_command' => 'マスタ（コーディネータ）昇格時に実行するコマンド',
     'descWd_heartbeat_deadtime' => '障害発生とみなすまでの猶予（秒）',
     'descWd_heartbeat_keepalive' => 'ハートビート信号を送信する間隔（秒）',
     'descWd_heartbeat_port' => 'ハートビート信号を受信するポート番号',
     'descWd_hostname' => 'watchdog プロセスが相互監視を受信するためのホスト名',
     'descWd_interval' => '死活監視の間隔(秒)',
+    'descWd_ipc_socket_dir' => 'watchdog の IPC（プロセス間通信）で受け付ける UNIX ドメインソケットが作成されるディレクトリ',
     'descWd_life_point' => '死活監視のリトライ回数',
     'descWd_lifecheck_dbname' => '死活監視を行なうために接続するデータベース',
     'descWd_lifecheck_method' => '死活監視の方法',
     'descWd_lifecheck_query' => '死活監視で実行するクエリ',
     'descWd_lifecheck_password' => '死活監視を行なうユーザのパスワード',
     'descWd_lifecheck_user' => '死活監視を行なうユーザ',
+    'descWd_monitoring_interfaces_list' => 'ネットワークリンクの状態を監視するネットワークデバイス名のリスト',
     'descWd_port' => 'watchdog プロセスが相互監視を受信するためのポート番号',
+    'descWd_priority' => '自身の watchdog ノードがリーダに選ばれる優先度',
     'descWhite_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
     'descWhite_memqcache_table_list' => 'SELECT結果をキャッシュしたいテーブル名のカンマ区切りのリスト',
 
@@ -174,6 +185,8 @@ $message = array(
     'errIllegalHostname' => '不正なホスト名です',
     'errIllegalPipe' => 'パイプの指定が不正です',
     'errInputEverything' => 'すべてを入力してください',
+    'errInvalidOwner' => '所有者が正しくありません',
+    'errInvalidPermission' => 'パーミッションが正しくありません',
     'errNoDefined' => 'パラメータが設定されていません',
     'errNotSameLength' => '列名リストと列データ型リストの配列の長さが一致しません。'.
                           '同じ要素数である必要があります。',
@@ -182,6 +195,7 @@ $message = array(
     'errShouldBeInteger' => '0以上の整数を入力してください',
     'errShouldBeZeroOrMore' => '0以上である必要があります',
     'errSingleQuotation' => '配列要素をシングルクォーテーションで囲んでください。',
+    'errWrongVersion' => 'pgpool コマンドと一致していません。',
 
     'msgAddBackend' => 'バックエンドノードとして追加してよろしいですか？',
     'msgAddBackendNg' => 'バックエンドノード情報に不備があります。',
@@ -382,6 +396,8 @@ $message = array(
     'e1010' => 'pcp_attach_nodeコマンドでエラーが発生しました',
     'e1011' => 'ログファイルが見つかりません',
     'e1012' => 'pcp_recovery_nodeコマンドでエラーが発生しました',
+    'e1013' => 'pcp_watchdog_infoコマンドでエラーが発生しました',
+    'e1014' => '.pcppass ファイルの読み込みに失敗しました',
     'e2001' => 'データベースに接続できません',
     'e2002' => 'レコード取得時にエラーが発生しました',
     'e2003' => 'pgpool.confが見つかりません',
